# coding: utf-8
from __future__ import absolute_import, with_statement

import os.path
import re
from itertools import chain
import argparse
import json
import subprocess
from ConfigParser import ConfigParser

import junkyardmap
import jinja2


parser = argparse.ArgumentParser(description='Creates a connection')

parser.add_argument('filename',
                    metavar='DESCRIPTION_FILE',
                    type=str,
                    help='filename for the connection description file')

parser.add_argument('--version', action='version', version=junkyardmap.version)

ALLOWED_HOSTNAME = re.compile(r'^([a-zA-Z0-9._-]+@)?[a-zA-Z0-9._-]+$')


def main():
    args = parser.parse_args()

    # read and parse file
    with open(args.filename, 'rb') as fp:
        data = json.load(fp)

    # check if data is secure
    for hop in data['hops']:
        if not ALLOWED_HOSTNAME.match(hop):
            raise RuntimeError("Illegal hop: %r" % hop)

    # read command template from user configuration
    config = ConfigParser()
    config.read([
        os.path.join(os.path.dirname(__file__), 'resources', 'default.ini'),
        os.path.expanduser('~/.junkyardmap'),
        # TODO: add windows location
    ])

    template = jinja2.Template(config.get('commands', 'connect'))

    # execute command
    subprocess.Popen(template.render(data=data), shell=True)
