#!/usr/bin/env python
# coding: utf-8
from __future__ import absolute_import, with_statement

import argparse
import yaml
import jinja2

from junkyardmap import version


parser = argparse.ArgumentParser(description='Generates a network overview.')

parser.add_argument('source',
                    metavar='SOURCE',
                    type=str,
                    help='The YAML-file from which to read the description.')

parser.add_argument('target',
                    metavar='TARGET',
                    type=str,
                    help='The filename to which the HTML '
                         'overview is rendered.')

parser.add_argument('--version', action='version', version=version)


env = jinja2.Environment(loader=jinja2.PackageLoader('junkyardmap',
                                                     'resources'))


def filter_base64(content):
    return content.encode("base64").replace('\n', '')


env.filters["base64"] = filter_base64

template = env.get_template('map.html')


def main():
    args = parser.parse_args()
    with open(args.source, 'rb') as source:
        data = yaml.load(source)
    with open(args.target, 'wb') as target:
        target.write(template.render(data).encode('utf-8'))


if __name__ == '__main__':
    main()
